# SEIRA
A python module for doing routine seismic near surface data processing

# Module Feature:
[1. Multichannel Analysis of Surface Wave]
  * [1.1 Plot data]
  * [1.2 Dispersion Curve]
  * [1.3 Picking Dispersion]
  * [1.4 Inversion]
